package com.mirs.biz.service;

import java.util.List;
import com.mirs.biz.domain.IntegratedData;

/**
 * 积分数据Service接口
 * 
 * @author kk
 * @date 2025-04-24
 */
public interface IIntegratedDataService 
{
    /**
     * 查询积分数据
     * 
     * @param id 积分数据主键
     * @return 积分数据
     */
    public IntegratedData selectIntegratedDataById(Long id);

    /**
     * 查询积分数据列表
     * 
     * @param integratedData 积分数据
     * @return 积分数据集合
     */
    public List<IntegratedData> selectIntegratedDataList(IntegratedData integratedData);

    /**
     * 新增积分数据
     * 
     * @param integratedData 积分数据
     * @return 结果
     */
    public int insertIntegratedData(IntegratedData integratedData);

    /**
     * 修改积分数据
     * 
     * @param integratedData 积分数据
     * @return 结果
     */
    public int updateIntegratedData(IntegratedData integratedData);

    /**
     * 批量删除积分数据
     * 
     * @param ids 需要删除的积分数据主键集合
     * @return 结果
     */
    public int deleteIntegratedDataByIds(Long[] ids);

    /**
     * 删除积分数据信息
     * 
     * @param id 积分数据主键
     * @return 结果
     */
    public int deleteIntegratedDataById(Long id);

    String importIntegratedData(List<IntegratedData> integratedDataList, boolean updateSupport, String operName);
}
